(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     49573,       1161]*)
(*NotebookOutlinePosition[     50652,       1200]*)
(*  CellTagsIndexPosition[     50546,       1193]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(Geomorphs\)], "Title",
  TextAlignment->Center,
  FontFamily->"Times New Roman"],

Cell[CellGroupData[{

Cell["How to run this program", "Section",
  FontFamily->"Times New Roman",
  FontSize->18],

Cell["\<\
Set the following path so that it matches the directory where you copied the \
geomorph files and this notebook:\
\>", "Text",
  FontSize->14],

Cell[BoxData[{
    \(\(programPath\  = \ "\<C:\My Documents\Geomorphs\>";\)\), "\
\[IndentingNewLine]", 
    \(\(SetDirectory[programPath];\)\)}], "Input",
  InitializationCell->True],

Cell["\<\
Setting the value of \"rootChoice\" below to 1, the initial geomorph is a \
flat disc. Setting it to 2,  the initial geomorph is a sphere.\
\>", "Text",
  FontSize->14],

Cell[BoxData[
    \(\(rootChoice\  = \ 2;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Now you are ready to use the program: Click once to the right of \
\"moreOptions[];\" (under the row of buttons) and hit Shift-Enter. This will \
generate a number of mutated geomorphs, starting from the current one. To \
change the current geomorph, click on button \"Load Geomorph\" and type the \
name of one of the sample files provided (you may omit the \".nb\" extension; \
use Windows Explorer to see the file names in the directory \"programPath\", \
as you typed it above).\
\>", "Text",
  FontSize->14],

Cell["\<\
To select one of the mutated geomorphs: click on button \"Make Choice\"; to \
save the current geomorph: click on \"Save Geomorph\".\
\>", "Text",
  FontSize->14],

Cell["\<\
You may change some of the parameters with the rest of the buttons. Before \
you click on \"Rotate\" make sure the cursor is right next to \"MoreOptions[]\
\". After the rotation frames are generated, you may see them rotated by \
double-clicking on the resulting geomorph.\
\>", "Text",
  FontSize->14],

Cell[TextData[{
  "Button \"Notebook\" allows you to \"export\" the current geomorph in a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook, which, when evaluated, produces a simple rotation of the \
surface. However, the idea is that you may change manually the parameter \
\"q\" which controls the Do-loop, so that instead of rotation you may see \
some other change of the surface, depending on where you use \"q\" in the \
definition."
}], "Text",
  FontSize->14],

Cell["\<\
You may collapse this set of instructions by double-clicking on the \
right-bracket which encloses this section (on the right margin \[Rule])\
\>", "Text",
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interface", "Section",
  FontFamily->"Times New Roman",
  FontSize->18],

Cell[BoxData[
    RowBox[{
      ButtonBox[\(Save\ Geomorph\),
        ButtonFunction:>saveGeomorph[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], " ", ";", 
      ButtonBox[\(Load\ Geomorph\),
        ButtonFunction:>loadGeomorph[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], ";", 
      ButtonBox[\(Make\ Choice\),
        ButtonFunction:>selectOption[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], ";", 
      ButtonBox[\(r\ Range\),
        ButtonFunction:>setRange1[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], ";", 
      ButtonBox[\(\[Theta]\ Range\),
        ButtonFunction:>setRange2[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], ";", 
      ButtonBox[\(r\ Points\),
        ButtonFunction:>setPoints1[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], ";", 
      ButtonBox[\(\[Theta]\ Points\),
        ButtonFunction:>setPoints2[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], ";", " ", 
      ButtonBox["Rotate",
        ButtonFunction:>rotateOption[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None], ";", " ", 
      ButtonBox[\(\(\[Rule]\)\(\ \)\(Notebook\)\),
        ButtonFunction:>printToNotebook[ ],
        ButtonEvaluator->"Local",
        Active->True,
        ButtonStyle->None]}]], "Input",
  CellTags->"Buttons"],

Cell[BoxData[
    \(\(moreOptions[];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Definition\ of\ Geomorphs\)], "Section",
  InitializationCell->True,
  FontFamily->"Times New Roman",
  FontSize->18],

Cell[BoxData[
    \(We\ want\ to\ experiment\ with\ 3 - \(\(dimensional\)\(\ \)\(surfaces\)\
\(\ \)\(whose\)\(\ \)\(parametric\)\(\ \)\(equations\)\(\ \)\(have\)\(\ \
\)\(the\)\(\ \)\(general\)\(\ \)\(form\)\(\ \)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[
    StyleBox[\(x \((u, \ 
            v)\)\ \  = \ \[Sum]\+\(i = 1\)\%n\[Product]\+\(j = 1\)\%m \
F\_ij\%x[p\_ij\%x]\[IndentingNewLine]
      b\[IndentingNewLine]
      y \((u, \ 
            v)\)\ \  = \ \[Sum]\+\(i = 1\)\%n\[Product]\+\(j = 1\)\%m \
F\_ij\%y[p\_ij\%y]\[IndentingNewLine]\[IndentingNewLine]
      z \((u, \ 
            v)\)\ \  = \ \[Sum]\+\(i = 1\)\%n\[Product]\+\(j = 1\)\%m \
F\_ij\%z[p\_ij\%z]\),
      FontSize->16]], "DisplayFormula",
  InitializationCell->True,
  TextAlignment->-0.5,
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
    \(where\ each\ F\_ij\ is\ a\ function\ drawn\ from\ a\ fixed\ list\ of\ \
functions\ that\ usually\ includes\ the\ zero\ function, \ 
    the\ identity\ function, 
    and\ basic\ trigonometric\ functions\ like\ Sin\ and\ Cos, 
    and\ each\ p\_\(i, j\)\ is\ a\ second\ degree\ polynomial\ on\ u, \ \(\(v\
\)\(\ \)\(which\)\(\ \)\(usually\)\(\ \)\(has\)\(\ \)\(just\)\(\ \)\(a\)\(\ \
\)\(few\)\(\ \)\(nonzero\)\(\ \)\(terms . \ 
        So\)\(\ \)\(each\)\(\ \)\(p\_ij\%\[Alpha]\) \(has\)\(\ \)\(the\)\(\ \
\)\(form\)\(\ \)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(p\_ij\%\[Alpha][u, \ v]\ \  = \ 
      a\_0\%\[Alpha]ij\  + \ \(a\_1\%\[Alpha]ij\) 
          u\  + \ \(a\_2\%\[Alpha]ij\) v\  + \ \(a\_3\%\[Alpha]ij\) 
          uv\  + \ \(a\_4\%\[Alpha]ij\) u\^2\  + \ \(a\_5\%\[Alpha]ij\) 
          v\^2\ , \ \ with\ \[Alpha]\ \[Epsilon]\ \(\({x, y, 
          z}\)\(.\)\)\)], "DisplayFormula",
  InitializationCell->True,
  TextAlignment->-0.5,
  FontSize->16],

Cell[BoxData[{
    RowBox[{\(By\ using\ the\ pattern\ above, \ 
      we\ can\ specify\ any\ concrete\ instance\ by\ \(providing : \ \
\[IndentingNewLine]\n\((1)\)\ An\ array\ F\ of\ dimensions\ 3  
              x\ n\ x\ m\ \ such\ that\ F[1, \ i, \ j]\) = \ 
        F\_\(i, j\)\%x, \ \ \ F[2, \ i, \ j] = \ 
        F\_\(i, j\)\%y, \ \ and\ \ \ F[3, \ i, \ j] = \ F\_\(i, j\)\%z\), 
      "\[IndentingNewLine]", "\t"}], "\n", 
    RowBox[{
      RowBox[{\(\((2)\)\ An\ array\ A\ of\ dimensions\ 3\ x\ n\ x\ m\ x\ 6\ \
such\ that\ A[\[Alpha], \ i, \ j, \ k]\), " ", "=", " ", 
        StyleBox[\(a\_k\%\[Alpha]ij\),
          FontSize->13]}], 
      "\[IndentingNewLine]"}], "\n", \(\((3)\)\ The\ range\ of\ values\ for\ \
u\ and\ v . \ \[IndentingNewLine]\[IndentingNewLine]This\ gives\ us\ a\ \
general\ idea\ of\ how\ a\ surface\ is\ going\ to\ be\ represented\ , \ \ but\
\ before\ attempting\ to\ build\ any\ example, \ 
    let' s\ \ define\ and\ initialize\ the\ global\ variables\ m, \ 
    n\ and\ the\ list\ of\ functions . \ Let' 
      s\ start\ by\ \ defining\ the\ zero\ and\ identity\ \
\(\(functions\)\(.\)\(\ \)\)\)}], "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Off[General::spell1];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Off[General::spell];\)\[IndentingNewLine]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[zero];\)\), "\[IndentingNewLine]", 
    \(\(zero[x_] := 0;\)\[IndentingNewLine] (*zero[arg___] := 
        Message[zero::badarg, \ HoldForm[zero[arg]]]; 
      HoldForm[zero[
          arg]]; \[IndentingNewLine]zero::badarg = "\<I accept only one \
numerical or symbolic argument. Error in `1`.\>";*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(Clear[one];\)\), "\[IndentingNewLine]", 
    \(\(one[x_] := 1;\)\[IndentingNewLine] (*one[arg___] := 
        Message[one::badarg, \ HoldForm[one[arg]]]; 
      HoldForm[one[
          arg]]; \[IndentingNewLine]one::badarg = "\<I accept only one \
numerical or symbolic argument. Error in `1`.\>";*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(Clear[id];\)\), "\[IndentingNewLine]", 
    \(\(id[x_] := x;\)\[IndentingNewLine] (*id[arg___] := 
        Message[id::badarg, \ HoldForm[id[arg]]]; 
      HoldForm[zero[
          arg]]; \[IndentingNewLine]id::badarg = "\<I accept only one \
numerical or symbolic argument. Error in `1`.\>";*) \)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Now\ let' 
      s\ give\ concrete\ values\ to\ n\ and\ m\ and\ define\ a\ short\ list\ \
of\ functions\ from\ which\ we' 
      ll\ pick\ the\ F\_ij' \(\(s\)\(\ \)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(n\  = \ 2; m = 3;\), "\[IndentingNewLine]", 
    \(\(functionList\  = \ {zero, \ one, \ id, \ Cos, \ Sin};\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(In\ order\ to\ treat\ surfaces\ as\ a\ data\ type, \ 
    we\ can\ introduce\ the\ head\ word\ Surface, \ 
    so\ that\ the\ surface\ defined\ by\ the\ array\ of\ functions\ fun, \ 
    the\ array\ of\ coefficients\ coef, \ 
    and\ the\ ranges\ urange\ and\ vrange\ for\ u\ and\ v\ is\ represented\ \
by\ the\ pattern\ Surface[fun, \ coef, \ urange, \ vrange] . \ 
        The\ following\ function\ performs\ a\ basic\ test\ on\ the\ type\ of\
\ the\ parameters\ of\ a\ Surface\ \(\(pattern\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[SurfaceQ];\)\), "\[IndentingNewLine]", 
    \(\(SurfaceQ[
          Surface[{__List}, \ {__List}, \ {_?NumberQ, \ _?NumberQ}, \ {_?
                NumberQ, \ _?NumberQ}]] := \ 
        True;\)\), "\[IndentingNewLine]", 
    \(\(SurfaceQ[arg___] := False;\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(We\ can\ define\ now\ some\ simple\ surfaces . \ For\ example, \ 
    we\ can\ define\ the\ circle\ of\ radius\ r\ centered\ in\ the\ z - 
      axis\ which\ is\ parallel\ to\ the\ xy\ plane\ at\ a\ distance\ d\ by\ \
applying\ \(\(horizontalCircle\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[{\(Clear[horizontalDisc];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(horizontalDisc[r_?NumberQ, \ d_?NumberQ]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({funx, \ funy, \ funz, \ fun, coefx, \ coefy, \ coefz, \ 
              coef, urange, \ vrange}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(urange = {0, \ r}\), 
              ";", \(vrange\  = {0, \ 2  \[Pi]}\), ";", "\[IndentingNewLine]",
               
              RowBox[{"funx", " ", "=", " ", 
                RowBox[{"(", GridBox[{
                      {"id", "Cos", "one"},
                      {"zero", "one", "one"}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"funy", "=", " ", 
                RowBox[{"(", GridBox[{
                      {"id", "Sin", "one"},
                      {"zero", "one", "one"}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"funz", " ", "=", " ", 
                RowBox[{"(", GridBox[{
                      {"id", "one", "one"},
                      {"zero", "one", "one"}
                      }], ")"}]}], ";", 
              "\[IndentingNewLine]", \(fun = {funx, funy, funz}\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"coefx", "=", " ", 
                RowBox[{"(", GridBox[{
                      {\({0, 1, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 1, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)},
                      {\({0, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"coefy", "=", " ", 
                RowBox[{"(", GridBox[{
                      {\({0, 1, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 1, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)},
                      {\({0, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"coefz", "=", " ", 
                RowBox[{"(", GridBox[{
                      {\({d, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)},
                      {\({0, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)}
                      }], ")"}]}], ";", 
              "\[IndentingNewLine]", \(coef = {coefx, coefy, coefz}\), ";", 
              "\[IndentingNewLine]", \(Surface[fun, coef, urange, \ 
                vrange]\)}]}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Needless\ to\ say, \ 
    this\ representation\ could\ be\ displayed\ in\ a\ nicer\ and\ clear\ way \
. \ Indeed, \ 
    since\ we\ are\ working\ with\ surfaces\ represented\ parametrically, \ 
    a\ basic\ thing\ we\ shoud\ be\ able\ to\ do\ is\ to\ recover\ the\ \
equations\ for\ the\ circle\ from\ the\ canonical\ representation\ given\ \
above . \ To\ do\ that, \ 
    we' ll\ use\ the\ following\ templates\ for\ polynomilas\ and\ parametric\
\ equations\ \ and\ the\ operations\ that\ Mathematica\ offers\ for\ \
manipulating\ lists . \ First, \ 
    we\ define\ a\ function\ that\ takes\ a\ list\ of\ coefficients\ and\ the\
\ name\ of\ two\ variables\ and\ returns\ the\ corresponding\ polynomial\)], \
"Text",
  InitializationCell->True,
  TextAlignment->Left,
  TextJustification->0],

Cell[BoxData[{
    \(\(Clear[makePoly];\)\), "\[IndentingNewLine]", 
    \(\(makePoly[{a_?NumberQ, \ b_?NumberQ, \ c_?NumberQ, \ d_?NumberQ, \ 
            e_?NumberQ, \ f_?NumberQ}, \ vars_List] := \ 
        Module[{u, v}, \[IndentingNewLine]u\  = \ 
            vars\[LeftDoubleBracket]1\[RightDoubleBracket]; \ 
          v = \ vars\[LeftDoubleBracket]2\[RightDoubleBracket]; \
\[IndentingNewLine]a\  + \ b\ u\  + \ c\ v\  + \ d\ u\ v\  + \ e\ u^2\  + 
            f\ v^2];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(For\ example\)\(,\)\(\ \)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(makePoly[{1, \ 2, \ 3, \ 4, \ 5, \ 6}, \ {r, \ \[Theta]}]\)], "Input"],

Cell[BoxData[
    \(Second, \ 
    we\ have\ a\ function\ that\ takes\ a\ list\ of\ coefficients, \ 
    a\ list\ of\ variables\ and\ a\ list\ of\ functions\ and\ returns\ a\ \
product\)], "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[makeFactor];\)\), "\[IndentingNewLine]", 
    \(\(makeFactor[fname_Symbol, \ coef_List, \ vars_List] := \ 
        fname[makePoly[coef, \ 
            vars]];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Clear[makeTerm];\)\), "\[IndentingNewLine]", 
    \(\(makeTerm[fun_List, \ coef_List, \ vars_List] := 
        Apply[Times, \ 
          MapThread[\((makeFactor[#1, \ #2, \ vars])\) &, \ {fun, \ 
              coef}]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Here\ is\ \ a\ \(\(test\)\(.\)\(\ \)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(makeTerm[{id, \ Cos, \ 
        one}, {{0, 1, \ 0, \ 0, \ 0, \ 0}, \ {0, 0, \ 1, \ 0, \ 0, \ 0}, {0, 
          0, \ 0, \ 0, \ 0, \ 0}\ }, \ {r, \ \[Theta]}]\)], "Input"],

Cell[BoxData[
    \(Now\ we\ can\ calculate\ the\ \(\(equations\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[makeSum];\)\), "\[IndentingNewLine]", 
    \(\(makeSum[\ fun_List, \ coef_List, \ vars_List] := 
        Apply[Plus, 
          MapThread[\((makeTerm[#1, \ #2, \ vars])\) &, \ {fun, \ 
              coef}]];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Clear[makeEquations];\)\), "\[IndentingNewLine]", 
    \(\(makeEquations[surf_Surface, \ vars_List] := \ 
        MapThread[\((makeSum[#1, \ #2, \ 
                vars])\) &, {\ \ surf\[LeftDoubleBracket]1\
\[RightDoubleBracket], \ 
            surf\[LeftDoubleBracket]2\[RightDoubleBracket]}];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Finally, \ 
    we\ can\ try\ with\ the\ equations\ for\ the\ \(\(disc\)\(.\)\(\ \)\)\)], \
"Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(disc1\  = \ horizontalDisc[2, \ 5]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Surface[{{{id, Cos, one}, {zero, one, one}}, {{id, Sin, one}, {zero, 
            one, one}}, {{id, one, one}, {zero, one, 
            one}}}, {{{{0, 1, 0, 0, 0, 0}, {0, 0, 1, 0, 0, 0}, {0, 0, 0, 0, 
              0, 0}}, {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
              0, 0}}}, {{{0, 1, 0, 0, 0, 0}, {0, 0, 1, 0, 0, 0}, {0, 0, 0, 0, 
              0, 0}}, {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
              0, 0}}}, {{{5, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
              0, 0}}, {{0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 0, 0}, {0, 0, 0, 0, 
              0, 0}}}}, {0, 2}, {0, 2\ \[Pi]}]\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(makeEquations[disc1, {r, \ \[Theta]}]\)], "Input"],

Cell[BoxData[{\(Clear[sphere];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(sphere[r_?NumberQ]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({funx, \ funy, \ funz, \ fun, coefx, \ coefy, \ coefz, \ 
              coef, urange, \ vrange}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(urange = {0, \ 2\ \[Pi]}\), 
              ";", \(vrange\  = {\(-\[Pi]\)/2, \ \[Pi]/2}\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"funx", " ", "=", " ", 
                RowBox[{"(", GridBox[{
                      {"id", "Cos", "Cos"},
                      {"zero", "one", "one"}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"funy", "=", " ", 
                RowBox[{"(", GridBox[{
                      {"id", "Sin", "Cos"},
                      {"zero", "one", "one"}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"funz", " ", "=", " ", 
                RowBox[{"(", GridBox[{
                      {"id", "Sin", "one"},
                      {"zero", "one", "one"}
                      }], ")"}]}], ";", 
              "\[IndentingNewLine]", \(fun = {funx, funy, funz}\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"coefx", "=", " ", 
                RowBox[{"(", GridBox[{
                      {\({r, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 1, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 1, \ 0, \ 0, \ 0}\)},
                      {\({0, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"coefy", "=", " ", 
                RowBox[{"(", GridBox[{
                      {\({r, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 1, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 1, \ 0, \ 0, \ 0}\)},
                      {\({0, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)}
                      }], ")"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"coefz", "=", " ", 
                RowBox[{"(", GridBox[{
                      {\({r, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 1, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)},
                      {\({0, 0, \ 0, \ 0, \ 0, \ 0}\), \({0, 0, \ 0, \ 0, \ 
                          0, \ 0}\), \({0, 0, \ 0, \ 0, \ 0, \ 0}\)}
                      }], ")"}]}], ";", 
              "\[IndentingNewLine]", \(coef = {coefx, coefy, coefz}\), ";", 
              "\[IndentingNewLine]", \(Surface[fun, coef, urange, \ 
                vrange]\)}]}], "]"}]}], ";"}]}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(unitSphere\  = \ sphere[1];\)\), "\[IndentingNewLine]", 
    \(makeEquations[unitSphere, \ {u, \ v}]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({Cos[u]\ Cos[v], Cos[v]\ Sin[u], Sin[v]}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mutations\ of\ Geomorphs\)], "Section",
  InitializationCell->True,
  FontFamily->"Times New Roman",
  FontSize->18],

Cell[BoxData[
    \(We\ first\ define\ a\ function\ that\ makes\ a\ biased\ random\ \
selection\ from\ a\ list\ of\ \(\(elements\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(biasedRandom[weights_List] := \ 
      Module[{wsum, \ r, \ tsum, \ i, \ len}, \[IndentingNewLine]wsum = \ 
          Apply[Plus, \ weights]; \[IndentingNewLine]r = \ 
          Random[Real, \ {0, wsum}]; \[IndentingNewLine]tsum\  = \ 
          0; \[IndentingNewLine]len\  = \ 
          Length[weights]; \[IndentingNewLine]i\  = \ 
          1; \[IndentingNewLine]While[
          tsum\  < \ r\ \  && \ \ i\  \[LessEqual] \ 
              len, \[IndentingNewLine]\ 
          tsum\  = \ 
            tsum\  + \ 
              weights\[LeftDoubleBracket]
                i\[RightDoubleBracket]; \[IndentingNewLine]\ 
          If[tsum\  < \ 
              r, \ \(i++\)]\[IndentingNewLine]]; \[IndentingNewLine]i\
\[IndentingNewLine]]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(biasedRandom[{2, 10, 1}]\)], "Input"],

Cell[BoxData[
    \(We\ need\ a\ function\ that\ makes\ a\ selection\ between\ functions\ \
\((weight\ w\_1)\)\ and\ coefficients\ \(\((weight\ w\_2)\)\(.\)\)\)], "Text",\

  InitializationCell->True],

Cell[BoxData[{
    \(\(w1\  = \ 0.2;\)\ \), "\[IndentingNewLine]", 
    \(\(w2\  = \ 0.8;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(funOrCoef := \ 
      If[biasedRandom[{w1, \ w2}] \[Equal] \ 
          1, \ "\<function\>", \ "\<coefficient\>"]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Here\ we\ give\ weights\ for\ the\ \(\(functions\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(functionList\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(fweights\  = {2, \ 9, \ 3, \ 3, \ 3}\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({zero, one, id, Cos, Sin}\)], "Output"],

Cell[BoxData[
    \({2, 9, 3, 3, 3}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(These\ are\ the\ weights\ for\ the\ coefficients\ of\ a\ polynomial\ \
a\_0 + \ a\_1\ u\  + \ \(a\_2\) v\  + \ \(a\_3\) u\ v\  + \ \(a\_4\) 
        u\^2\  + \ \(a\_5\) v\^2 . \ The\ i - 
      th\ weight\ corresponds\ to\ \(\(a\_\(i - 1\)\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(cweights\  = \ {5, \ 10, \ 10, \ 1, \ 1, 1}\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({5, 10, 10, 1, 1, 1}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(Here\ we\ give\ a\ procedure\ to\ select\ the\ value\ of\ a\ \
coefficient\ at\ random . \ 
        For\ now\ we\ assume\ the\ range\ of\ coefficients\ \(\(is\ [\(-3\), \
\ 3]\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(randomCoefValue := \ Rationalize[Random[Real, {\(-3\), 3}]]\)], "Input",\

  InitializationCell->True],

Cell[BoxData[
    \(Now\ we\ can\ put\ all\ of\ this\ together\ to\ generate\ a\ mutated\ \
surface . \ First, \ 
    the\ code\ that\ defines\ the\ mutation . \ 
        It\ returns\ the\ path\ to\ the\ leaf\ to\ be\ changed\ and\ the\ new\
\ \(\(value\)\(.\)\)\)], "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[newMutation];\)\), "\[IndentingNewLine]", 
    \(newMutation[sur_Surface] := \ 
      Module[{kind, \ path, \ value, \ old}, \ \[IndentingNewLine]kind\  = \ 
          funOrCoef; \[IndentingNewLine]If[
          kind\  \[Equal] \ \ "\<function\>", \ \[IndentingNewLine]path\  = \ \
{1, \ Random[Integer, \ {1, \ 3}], Random[Integer, \ {1, \ n}], 
              Random[Integer, \ {1, \ 
                  m}]\ }; \[IndentingNewLine]value\  = \ \ functionList\
\[LeftDoubleBracket]biasedRandom[
                fweights]\[RightDoubleBracket], \[IndentingNewLine] (*\ 
            Else\ *) \[IndentingNewLine]path\  = \ {2, \ 
              Random[Integer, \ {1, \ 3}], Random[Integer, \ {1, \ n}], 
              Random[Integer, \ {1, \ m}], \ 
              biasedRandom[cweights]\ }; \[IndentingNewLine]value\  = \ 
            randomCoefValue\[IndentingNewLine]]; \[IndentingNewLine]old\  = \ 
          Extract[sur, path]; \[IndentingNewLine]{path, \ value, \ 
          old}\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[applyMutation];\)\), "\[IndentingNewLine]", 
    \(applyMutation[sur_Surface] := \ 
      Module[{mutation}, \[IndentingNewLine]{mutation = \ 
            newMutation[sur], \[IndentingNewLine]ReplacePart[sur, \ 
            mutation\[LeftDoubleBracket]2\[RightDoubleBracket], \ 
            mutation\[LeftDoubleBracket]1\[RightDoubleBracket]]}\
\[IndentingNewLine]]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Let' 
      s\ initialize\ a\ geomorph\ and\ save\ it\ as\ the\ root\ of\ a\ tree . \
\ First, \ 
    we\ define\ a\ matrix\ whose\ rows\ give\ different\ possibilities\ for\ \
roots . \ 
        The\ first\ column\ is\ the\ name\ of\ the\ root\ geomorph\ and\ the\ \
second\ is\ the\ name\ of\ the\ file\ where\ the\ root\ is\ \
\(\(saved\)\(.\)\(\ \)\)\)], "Text"],

Cell["\<\
NOTE: variable rootChoice, used below, has been set in initial section \"How \
to run this program\".\
\>", "Text",
  FontFamily->"Courier New",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[{
    RowBox[{
      RowBox[{
        RowBox[{"gmArray", " ", "=", " ", 
          RowBox[{"(", GridBox[{
                {"disc1", "\"\<disc.nb\>\""},
                {"unitSphere", "\"\<sphere.nb\>\""}
                }], ")"}]}], ";"}], 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", \(rootFile\  = 
        gmArray\[LeftDoubleBracket]rootChoice, \ 
          2\[RightDoubleBracket];\), "\[IndentingNewLine]", \(geomorph\  = \ 
        gmArray\[LeftDoubleBracket]rootChoice, \ 
          1\[RightDoubleBracket];\), "\[IndentingNewLine]", \(ancestorFile\  \
= \ "\<None\>";\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(The\ initialization\ of\ the\ ranges\ and\ points\ of\ the\ two\ free\ \
variables\ \(\(follows\)\(.\)\)\)], "Text"],

Cell[BoxData[{
    \(r\_min = 
      geomorph\[LeftDoubleBracket]3, 1\[RightDoubleBracket]; \ \ r\_max = 
      geomorph\[LeftDoubleBracket]3, 2\[RightDoubleBracket];\), "\n", 
    \(\[Theta]\_min = 
      geomorph\[LeftDoubleBracket]4, 
        1\[RightDoubleBracket]; \ \ \[Theta]\_max = 
      geomorph\[LeftDoubleBracket]4, 2\[RightDoubleBracket];\), "\n", 
    \(\(rPoints\  = \ Ceiling[10\ *\ \((r\_max - r\_min)\)];\)\), "\n", 
    \(\(\[Theta]Points\  = \ 
        Ceiling[10\ *\ \((\[Theta]\_max - \[Theta]\_min)\)];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(mutationPath\  = \ {};\)\[IndentingNewLine]\), "\[IndentingNewLine]", \

    \(\(If[FileNames[rootFile] == {}, \ 
        saveGeomorph[rootFile]];\)\), "\[IndentingNewLine]", 
    \(\(ancestorFile\  = rootFile;\)\)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Interface\ Functions\)], "Section",
  InitializationCell->True,
  FontFamily->"Times New Roman",
  FontSize->18],

Cell["\<\
The following function (chooseSurfaceId) is used by most of the interface \
functions for selecting a surface to work on.\
\>", "Text",
  InitializationCell->True,
  FontFamily->"Courier New"],

Cell[BoxData[{\(Clear[chooseSurfaceId];\), "\[IndentingNewLine]", 
    RowBox[{\(chooseSurfaceId[restOfPrompt_] := 
          Module[{choiceId, \ choiceStr, \ 
              prompt}, \[IndentingNewLine]prompt = "\<Which surface you want \
to \>" <> 
                restOfPrompt <> "\< (leave blank to cancel, enter 0 for \
current surface, or any number \[GreaterEqual] 1 for the other surfaces):\>"; \
\[IndentingNewLine]choiceStr = InputString[prompt]; \[IndentingNewLine]If[
              choiceStr \[Equal] "\<\>", \[IndentingNewLine]choiceId = \
\(-1\), \[IndentingNewLine]\(choiceId = 
                  N[ToExpression[
                      choiceStr]];\)\[IndentingNewLine]]; \
\[IndentingNewLine]choiceId\[IndentingNewLine]];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(chooseSurfaceId::usage\), "=", "\"\<\!\(\*
StyleBox[\\\"chooseSurfaceId\\\",\\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\\\"[\\\",\\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\\\"prompt\\\",\\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\\\"]\\\",\\nFontColor->RGBColor[1, 0, 0]]\) asks the user to enter \
a number to select one of the proposed surfaces, or 0 for selecting the \
current surface. Parameter 'prompt' is part of the prompt displayed to the \
user.\>\""}], ";"}]}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[saveGeomorph];\)\), "\[IndentingNewLine]", 
    \(\(saveGeomorph[givenFile_: "\<\>"] := 
        Module[{newFile, \ chosen, \ 
            savedGeomorph}, \[IndentingNewLine]chosen\  = \ 
            chooseSurfaceId["\<save?\>"]; \[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 0\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]If[chosen\  \[NotEqual] \ 0, \ 
              savedGeomorph = geomorph; \ 
              geomorph = 
                options\[LeftDoubleBracket]2, \ 
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]newFile\  \
= \ givenFile; \[IndentingNewLine]If[newFile\  \[Equal] \ "\<\>", \ 
              newFile = 
                InputString["\<Enter a file name to save geomorph to (leave \
blank to skip; extension .nb will be added automatically if you don't type it \
explicitly):\>"]]; \[IndentingNewLine]If[
                newFile\  \[NotEqual] \ "\<\>", \[IndentingNewLine]If[\[Not] \
StringMatchQ[newFile, \ "\<*.nb\>"], \ 
                  newFile\  = \ 
                    newFile\  <> \ "\<.nb\>"]; \[IndentingNewLine]If[
                  FileNames[newFile] \[NotEqual] {}, \ 
                  DeleteFile[newFile]]; \[IndentingNewLine] (*\ 
                  The\ following\ 4\ assignments\ are\ a\ consequence\ of\ \
not\ being\ able\ to\ Save[]\ the\ indexed\ variables\ \(\(normally\)\(.\)\)\ \
*) \[IndentingNewLine]rmin\  = \ r\_min; \[IndentingNewLine]rmax\  = \ 
                  r\_max; \[IndentingNewLine]\[Theta]min\  = \ \[Theta]\_min; \
\[IndentingNewLine]\[Theta]max\  = \ \[Theta]\_max; \[IndentingNewLine]Save[
                  newFile, \ ancestorFile, \ mutationPath, \ geomorph, \ 
                  rPoints, \ \[Theta]Points, \ 
                  rmin, \ \ rmax, \ \[Theta]min, \ \ \[Theta]max]; \
\[IndentingNewLine]ancestorFile\  = \ 
                  newFile; \[IndentingNewLine]mutationPath\  = \ {}\
\[IndentingNewLine]]\[IndentingNewLine]If[chosen\  \[NotEqual] \ 0, \ 
                geomorph\  = \ 
                  savedGeomorph];\[IndentingNewLine]]\[IndentingNewLine]];\)\)\
}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[loadGeomorph];\)\), "\[IndentingNewLine]", 
    \(\(loadGeomorph[] := 
        Module[{oldFile}, \[IndentingNewLine]oldFile = 
            InputString["\<Enter a file name to load geomorph from:\>"]; \
\[IndentingNewLine]If[FileNames[oldFile] == {}, \ 
            oldFile\  = \ oldFile\  <> \ "\<.nb\>"]; \[IndentingNewLine]If[
            FileNames[
                oldFile] == {}, \ \[IndentingNewLine]Print["\<File \>"\  <> \ 
                oldFile\  <> \ "\< does not exist.\>"], \[IndentingNewLine] \
(*\ else\ *) \[IndentingNewLine]Get[oldFile]; \[IndentingNewLine] (*\ 
              The\ following\ 4\ assignments\ are\ a\ consequence\ of\ saving\
\ the\ indexed\ variables\ in\ a\ special\ \(\(way\)\(.\)\)\ \
*) \[IndentingNewLine]r\_min\  = \ rmin; \[IndentingNewLine]r\_max\  = \ 
              rmax\ ; \[IndentingNewLine]\[Theta]\_min\  = \ \[Theta]min; \
\[IndentingNewLine]\[Theta]\_max\  = \ \[Theta]max; \
\[IndentingNewLine]ancestorFile\  = \ 
              oldFile; \[IndentingNewLine]mutationPath\  = \ {}]];\)\)}], \
"Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[selectOption];\)\), "\[IndentingNewLine]", 
    \(\(selectOption[] := 
        Module[{chosen}, \[IndentingNewLine]chosen\  = \ 
            Input["\<Which surface you like better? (1 - 3; to skip, enter 0)\
\>"]; \[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 1\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]mutationPath\  = \ 
              Append[mutationPath, \ 
                options\[LeftDoubleBracket]1, 
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]geomorph\  \
= \ options\[LeftDoubleBracket]2, 
                chosen\[RightDoubleBracket]]\[IndentingNewLine]];\)\)}], \
"Input",
  InitializationCell->True],

Cell[BoxData[{\(Clear[deleteRangePlot];\), "\[IndentingNewLine]", 
    RowBox[{\(deleteRangePlot[] := 
          Module[{nb}, \[IndentingNewLine]nb = 
              EvaluationNotebook[]; \
\[IndentingNewLine]NotebookLocate["\<Buttons\>"]; \
\[IndentingNewLine]SelectionMove[nb, \ Next, \ 
              Cell]; \[IndentingNewLine]FrontEndTokenExecute["\<Cut\>"]; \
\[IndentingNewLine]NotebookLocate["\<Buttons\>"]\[IndentingNewLine]];\), 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(deleteRangePlot::usage\), "=", "\"\<\!\(\*
StyleBox[\\\"deleteRangePlot\\\",\\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\\\"[\\\",\\nFontColor->RGBColor[1, 0, 0]]\)\!\(\*
StyleBox[\\\"]\\\",\\nFontColor->RGBColor[1, 0, 0]]\) selects the cell tagged \
Buttons and deletes the next cell which is the output of one of the \
buttons.\>\""}], ";"}]}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[setRange1];\)\), "\[IndentingNewLine]", 
    \(\(setRange1[] := 
        Module[{chosen, \ lim1, \ lim2, \ yes, \ 
            surface}, \[IndentingNewLine]chosen\  = \ 
            chooseSurfaceId["\<see with a different range for r?\>"]; \
\[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 0\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]If[chosen\  \[Equal] \ 0, \ 
              surface = makeEquations[geomorph, {r, \ \[Theta]}], 
              surface = 
                eqList\[LeftDoubleBracket]
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]lim1 = 
              InputString["\<Enter new LOW value for r (current value is \>"\ \
 <> \ ToString[
                    r\_min]\  <> \ "\<; blank retains the current \
value):\>"]; \[IndentingNewLine]If[lim1\  \[NotEqual] \ "\<\>", \ 
              lim1 = ToExpression[lim1], \ 
              lim1 = r\_min]; \[IndentingNewLine]lim2 = 
              InputString["\<Enter new HIGH value for r (current value is \>"\
\  <> \ ToString[
                    r\_max]\  <> \ "\<; blank retains the current \
value):\>"]; \[IndentingNewLine]If[lim2\  \[NotEqual] \ "\<\>", \ 
              lim2 = ToExpression[lim2], \ 
              lim2 = r\_max]; \[IndentingNewLine]ParametricPlot3D[
              surface, {r, \ lim1, \ 
                lim2}, \ {\[Theta], \ \[Theta]\_min, \[Theta]\_max}, \ \ \ \
Boxed\  \[Rule] \ False, \ Axes\  \[Rule] \ False, \ 
              Compiled\  \[Rule] \ False, \ 
              PlotPoints \[Rule] {rPoints, \ \[Theta]Points}]; \
\[IndentingNewLine]yes\  = \ 
              InputString["\<Would you like this to be the new range for \
r?\>"]; \[IndentingNewLine]If[
              yes\  \[Equal] \ "\<yes\>"\  || \ 
                yes\  \[Equal] \ "\<Yes\>"\  || \ yes\  \[Equal] \ "\<YES\>", 
              r\_min\  = \ lim1; 
              r\_max\  = \ 
                lim2]; \[IndentingNewLine]deleteRangePlot[]\[IndentingNewLine]\
];\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[setRange2];\)\), "\[IndentingNewLine]", 
    \(\(setRange2[] := 
        Module[{chosen, \ lim1, \ lim2, \ yes, \ 
            surface}, \[IndentingNewLine]chosen\  = \ 
            chooseSurfaceId["\<see with a different range for theta?\>"]; \
\[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 0\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]If[chosen\  \[Equal] \ 0, \ 
              surface = makeEquations[geomorph, {r, \ \[Theta]}], 
              surface = 
                eqList\[LeftDoubleBracket]
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]lim1 = 
              InputString["\<Enter new LOW value for theta (current value is \
\>"\  <> \ 
                  ToString[\[Theta]\_min]\  <> \ "\<; blank retains the \
current value):\>"]; \[IndentingNewLine]If[lim1\  \[NotEqual] \ "\<\>", \ 
              lim1 = ToExpression[lim1], \ 
              lim1 = \[Theta]\_min]; \[IndentingNewLine]lim2 = 
              InputString["\<Enter new HIGH value for theta (current value is \
\>"\  <> \ 
                  ToString[\[Theta]\_max]\  <> \ "\<; blank retains the \
current value):\>"]; \[IndentingNewLine]If[lim2\  \[NotEqual] \ "\<\>", \ 
              lim2 = ToExpression[lim2], \ 
              lim2 = \[Theta]\_max]; \[IndentingNewLine]ParametricPlot3D[
              surface, {r, \ r\_min, \ r\_max}, \ {\[Theta], \ lim1, 
                lim2}, \ \ \ Boxed\  \[Rule] \ False, \ 
              Axes\  \[Rule] \ False, \ Compiled\  \[Rule] \ False, \ 
              PlotPoints \[Rule] {rPoints, \ \[Theta]Points}]; \
\[IndentingNewLine]yes\  = \ 
              InputString["\<Would you like this to be the new range for \
theta?\>"]; \[IndentingNewLine]If[
              yes\  \[Equal] \ "\<yes\>"\  || \ 
                yes\  \[Equal] \ "\<Yes\>"\  || \ 
                yes\  \[Equal] \ "\<YES\>", \[Theta]\_min\  = \ 
                lim1; \[Theta]\_max\  = \ 
                lim2]; \[IndentingNewLine]deleteRangePlot[]\[IndentingNewLine]\
];\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[setPoints1];\)\), "\[IndentingNewLine]", 
    \(\(setPoints1[] := 
        Module[{chosen, \ pts, \ yes, \ 
            surface}, \[IndentingNewLine]chosen\  = \ 
            chooseSurfaceId["\<see with a different number of points for \
r?\>"]; \[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 0\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]If[chosen\  \[Equal] \ 0, \ 
              surface = makeEquations[geomorph, {r, \ \[Theta]}], 
              surface = 
                eqList\[LeftDoubleBracket]
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]pts = 
              InputString["\<Enter new number of points for r (current value \
is \>"\  <> \ ToString[
                    rPoints]\  <> \ "\<; blank retains the current \
value):\>"]; \[IndentingNewLine]If[pts\  \[NotEqual] \ "\<\>", \ 
              pts = ToExpression[pts], \ 
              pts = rPoints]; \[IndentingNewLine]ParametricPlot3D[
              surface, {r, \ r\_min, \ 
                r\_max}, \ {\[Theta], \ \[Theta]\_min, \[Theta]\_max}, \ \ \ \
Boxed\  \[Rule] \ False, \ Axes\  \[Rule] \ False, \ 
              Compiled\  \[Rule] \ False, \ 
              PlotPoints \[Rule] {pts, \ \[Theta]Points}]; \
\[IndentingNewLine]yes\  = \ 
              InputString["\<Would you like this to be the new number of \
points for r?\>"]; \[IndentingNewLine]If[
              yes\  \[Equal] \ "\<yes\>"\  || \ 
                yes\  \[Equal] \ "\<Yes\>"\  || \ yes\  \[Equal] \ "\<YES\>", 
              rPoints\  = \ 
                pts]; \[IndentingNewLine]deleteRangePlot[]\[IndentingNewLine]]\
;\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[setPoints2];\)\), "\[IndentingNewLine]", 
    \(\(setPoints2[] := 
        Module[{chosen, \ pts, \ yes, \ 
            surface}, \[IndentingNewLine]chosen\  = \ 
            chooseSurfaceId["\<see with a different number of points for \
theta?\>"]; \[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 0\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]If[chosen\  \[Equal] \ 0, \ 
              surface = makeEquations[geomorph, {r, \ \[Theta]}], 
              surface = 
                eqList\[LeftDoubleBracket]
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]pts = 
              InputString["\<Enter new number of points for theta (current \
value is \>"\  <> \ 
                  ToString[\[Theta]Points]\  <> \ "\<; blank retains the \
current value):\>"]; \[IndentingNewLine]If[pts\  \[NotEqual] \ "\<\>", \ 
              pts = ToExpression[pts], \ 
              pts = \[Theta]Points]; \[IndentingNewLine]ParametricPlot3D[
              surface, {r, \ r\_min, \ 
                r\_max}, \ {\[Theta], \ \[Theta]\_min, \[Theta]\_max}, \ \ \ \
Boxed\  \[Rule] \ False, \ Axes\  \[Rule] \ False, \ 
              Compiled\  \[Rule] \ False, \ 
              PlotPoints \[Rule] {rPoints, \ 
                  pts}]; \[IndentingNewLine]yes\  = \ 
              InputString["\<Would you like this to be the new number of \
points for theta?\>"]; \[IndentingNewLine]If[
              yes\  \[Equal] \ "\<yes\>"\  || \ 
                yes\  \[Equal] \ "\<Yes\>"\  || \ 
                yes\  \[Equal] \ "\<YES\>", \[Theta]Points\  = \ 
                pts]; \[IndentingNewLine]deleteRangePlot[]\[IndentingNewLine]]\
;\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(<< Graphics`Animation`\)], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[rotateOption];\)\), "\[IndentingNewLine]", 
    \(\(rotateOption[] := 
        Module[{chosen, \ lim1, \ lim2, \ yes, \ nb, \ gr, \ 
            surface}, \[IndentingNewLine]chosen\  = \ 
            chooseSurfaceId["\<rotate?\>"]; \[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 0\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]If[chosen\  \[Equal] \ 0, \ 
              surface = makeEquations[geomorph, {r, \ \[Theta]}], 
              surface = 
                eqList\[LeftDoubleBracket]
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]gr\  = \ 
              ParametricPlot3D[
                surface, {r, \ r\_min, \ 
                  r\_max}, \ {\[Theta], \ \[Theta]\_min, \[Theta]\_max}, \ \ \
\ Boxed\  \[Rule] \ False, \ Axes\  \[Rule] \ False, \ 
                Compiled\  \[Rule] \ False, \ 
                DisplayFunction \[Rule] Identity, \ 
                PlotPoints \[Rule] {rPoints, \ \[Theta]Points}]; \
\[IndentingNewLine]SpinShow[gr]; \[IndentingNewLine]nb = 
              EvaluationNotebook[]; \[IndentingNewLine]SelectionMove[nb, \ 
              Next, \ CellGroup]; \
\[IndentingNewLine]FrontEndTokenExecute["\<OpenCloseGroup\>"];\
\[IndentingNewLine]];\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[printToNotebook];\)\), "\[IndentingNewLine]", 
    \(\(printToNotebook[] := 
        Module[{chosen, \ strm, \ fileName, \ surf, \ 
            tmp}, \[IndentingNewLine]chosen\  = \ 
            chooseSurfaceId["\<examine in a separate notebook?\>"]; \
\[IndentingNewLine]If[
            chosen\  \[GreaterEqual] \ 0\ \  && \ \ chosen\  \[LessEqual] \ 
                3, \[IndentingNewLine]If[chosen\  \[Equal] \ 0, \ 
              surf = geomorph, 
              surf = options\[LeftDoubleBracket]2, \ 
                  chosen\[RightDoubleBracket]]; \[IndentingNewLine]fileName\  \
= \ InputString["\<Enter the name of the notebook to print the geomorph into \
(leave blank to skip; extension .nb will be added automatically if you don't \
type it explicitly):\>"]; \[IndentingNewLine]If[
              fileName\  \[NotEqual] \ "\<\>", \[IndentingNewLine]If[\[Not] \
StringMatchQ[fileName, \ "\<*.nb\>"], \ 
                fileName\  = \ 
                  fileName\  <> \ "\<.nb\>"]; \[IndentingNewLine]strm\  = \ 
                NotebookCreate[]; \[IndentingNewLine]NotebookWrite[strm, 
                ReplacePart[
                  Cell[BoxData[
                      MakeBoxes[
                        Do[ParametricPlot3D["\<tmp\>", \ {r, \ r\_min, 
                              r\_max}, {u, \[Theta]\_min, \[Theta]\_max}, 
                            PlotPoints\  \[Rule] {\ 
                                rPoints, \[Theta]Points}, \ 
                            ViewPoint \[Rule] {2*Sin[q], 2*Cos[q], 2}, \ 
                            Background\  \[Rule] \ 
                              RGBColor[0.015625, \ 0.390625, \ 0.015625], \ 
                            DefaultColor\  \[Rule] \ 
                              RGBColor[0.0, \ 0.0, \ 0.0], \ 
                            SphericalRegion\  \[Rule] \ True, \ 
                            Boxed\  \[Rule] \ False, \ 
                            Axes\  \[Rule] \ False, \ 
                            ImageSize\  \[Rule] \ 550], {q, \ 0, \ 
                            2  \[Pi], \ \[Pi]/8}]]], \ 
                    Evaluatable \[Rule] True], \[IndentingNewLine]ToBoxes[
                    makeEquations[surf, \ {r, \ u}]], \[IndentingNewLine]{1, 
                    1, 1, \ 3, 1, 1, 1, 3, 1, 
                    1}]]; \[IndentingNewLine]NotebookSave[strm, \ 
                fileName]\[IndentingNewLine]]\[IndentingNewLine]]\
\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True],

Cell[BoxData[{
    \(\(Clear[moreOptions];\)\), "\[IndentingNewLine]", 
    \(\(moreOptions[] := 
        Module[{eq, \ 
            array}, \[IndentingNewLine]Print["\<Current geomorph: \>", \ 
            eq\  = \ makeEquations[
                geomorph, {r, \ \[Theta]}]]; \[IndentingNewLine]options\  = \ 
            Transpose[
              Table[\ applyMutation[geomorph], \ {i, \ 1, \ 
                  3}]]; \[IndentingNewLine]Print["\<Mutations:\>"]; \
\[IndentingNewLine]Print[
            TableForm[
              eqList = \ 
                Map[\((makeEquations[#1, {r, \ \[Theta]}])\) &, \ 
                  options\[LeftDoubleBracket]2\[RightDoubleBracket]]]]; \
\[IndentingNewLine]Print["\<Images of mutations:\>"]; \
\[IndentingNewLine]array\  = \ 
            Map[\((ParametricPlot3D[#1, {r, \ r\_min, \ 
                      r\_max}, \ {\[Theta], \ \[Theta]\_min, \[Theta]\_max}, \
\ \ \ Boxed\  \[Rule] \ False, \ Axes\  \[Rule] \ False, \ 
                    Compiled\  \[Rule] \ False, 
                    DisplayFunction \[Rule] Identity, \ 
                    PlotPoints \[Rule] {rPoints, \ \[Theta]Points}])\) &, \ 
              eqList]; \[IndentingNewLine]Show[GraphicsArray[array], \ 
            ImageSize\  \[Rule] \ 
              750]; \[IndentingNewLine]NotebookLocate["\<Buttons\>"];\
\[IndentingNewLine]];\)\)}], "Input",
  InitializationCell->True,
  CellTags->"MoreOptions"],

Cell[BoxData[
    \(\(NotebookOpen[Directory[]\  <> \ "\<\GeoPalette.nb\>"];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(About\ this\ Notebook\)], "Section",
  FontFamily->"Times New Roman",
  FontSize->18],

Cell[BoxData[
    \(\(This\ project\ \((idea\  + \ 
              implementation)\)\ was\ created\ by\ Maricarmen\ Martinez\  &\)\
\ Harry\ E . \ Foundalis, \ ca . \ June - October\ 2001. \)], "Text",
  FontFamily->"Lucida Sans",
  FontSize->16]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->"EditBar",
WindowSize->{1014, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowCellTags->True,
StyleDefinitions -> "Default.nb"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Buttons"->{
    Cell[4369, 134, 1561, 47, 47, "Input",
      CellTags->"Buttons"]},
  "MoreOptions"->{
    Cell[47644, 1111, 1417, 28, 284, "Input",
      InitializationCell->True,
      CellTags->"MoreOptions"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Buttons", 50319, 1182},
  {"MoreOptions", 50410, 1185}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 100, 3, 103, "Title"],

Cell[CellGroupData[{
Cell[1864, 58, 91, 2, 54, "Section"],
Cell[1958, 62, 152, 4, 34, "Text"],
Cell[2113, 68, 183, 4, 50, "Input",
  InitializationCell->True],
Cell[2299, 74, 178, 4, 34, "Text"],
Cell[2480, 80, 84, 2, 30, "Input",
  InitializationCell->True],
Cell[2567, 84, 522, 9, 74, "Text"],
Cell[3092, 95, 172, 4, 34, "Text"],
Cell[3267, 101, 313, 6, 54, "Text"],
Cell[3583, 109, 485, 10, 74, "Text"],
Cell[4071, 121, 181, 4, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4289, 130, 77, 2, 54, "Section"],
Cell[4369, 134, 1561, 47, 47, "Input",
  CellTags->"Buttons"],
Cell[5933, 183, 51, 1, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6021, 189, 137, 4, 54, "Section",
  InitializationCell->True],
Cell[6161, 195, 255, 4, 31, "Text",
  InitializationCell->True],
Cell[6419, 201, 591, 15, 219, "DisplayFormula",
  InitializationCell->True],
Cell[7013, 218, 584, 10, 72, "Text",
  InitializationCell->True],
Cell[7600, 230, 418, 9, 31, "DisplayFormula",
  InitializationCell->True],
Cell[8021, 241, 1173, 21, 205, "Text",
  InitializationCell->True],
Cell[9197, 264, 184, 3, 90, "Input",
  InitializationCell->True],
Cell[9384, 269, 1081, 21, 290, "Input",
  InitializationCell->True],
Cell[10468, 292, 231, 5, 32, "Text",
  InitializationCell->True],
Cell[10702, 299, 171, 3, 50, "Input",
  InitializationCell->True],
Cell[10876, 304, 562, 9, 69, "Text",
  InitializationCell->True],
Cell[11441, 315, 328, 7, 70, "Input",
  InitializationCell->True],
Cell[11772, 324, 317, 5, 50, "Text",
  InitializationCell->True],
Cell[12092, 331, 2808, 52, 350, "Input",
  InitializationCell->True],
Cell[14903, 385, 815, 16, 107, "Text",
  InitializationCell->True],
Cell[15721, 403, 521, 9, 110, "Input",
  InitializationCell->True],
Cell[16245, 414, 91, 2, 31, "Text",
  InitializationCell->True],
Cell[16339, 418, 90, 1, 30, "Input"],
Cell[16432, 421, 224, 5, 31, "Text",
  InitializationCell->True],
Cell[16659, 428, 506, 10, 110, "Input",
  InitializationCell->True],
Cell[17168, 440, 98, 2, 31, "Text",
  InitializationCell->True],
Cell[17269, 444, 190, 3, 30, "Input"],
Cell[17462, 449, 112, 2, 31, "Text",
  InitializationCell->True],
Cell[17577, 453, 632, 12, 110, "Input",
  InitializationCell->True],
Cell[18212, 467, 147, 4, 31, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[18384, 475, 95, 2, 30, "Input",
  InitializationCell->True],
Cell[18482, 479, 670, 9, 70, "Output"]
}, Open  ]],
Cell[19167, 491, 70, 1, 30, "Input"],
Cell[19240, 494, 2795, 52, 330, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[22060, 550, 165, 3, 50, "Input",
  InitializationCell->True],
Cell[22228, 555, 74, 1, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[22351, 562, 136, 4, 34, "Section",
  InitializationCell->True],
Cell[22490, 568, 177, 3, 31, "Text",
  InitializationCell->True],
Cell[22670, 573, 795, 17, 250, "Input",
  InitializationCell->True],
Cell[23468, 592, 57, 1, 30, "Input"],
Cell[23528, 595, 200, 4, 31, "Text",
  InitializationCell->True],
Cell[23731, 601, 299, 6, 90, "Input",
  InitializationCell->True],
Cell[24033, 609, 117, 2, 31, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[24175, 615, 164, 3, 70, "Input",
  InitializationCell->True],
Cell[24342, 620, 59, 1, 70, "Output"],
Cell[24404, 623, 49, 1, 70, "Output"]
}, Open  ]],
Cell[24468, 627, 308, 5, 31, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[24801, 636, 104, 2, 30, "Input",
  InitializationCell->True],
Cell[24908, 640, 54, 1, 70, "Output"]
}, Open  ]],
Cell[24977, 644, 244, 5, 31, "Text",
  InitializationCell->True],
Cell[25224, 651, 122, 3, 30, "Input",
  InitializationCell->True],
Cell[25349, 656, 302, 6, 50, "Text",
  InitializationCell->True],
Cell[25654, 664, 1068, 18, 270, "Input",
  InitializationCell->True],
Cell[26725, 684, 436, 8, 110, "Input",
  InitializationCell->True],
Cell[27164, 694, 386, 8, 69, "Text"],
Cell[27553, 704, 186, 5, 33, "Text"],
Cell[27742, 711, 638, 14, 122, "Input",
  InitializationCell->True],
Cell[28383, 727, 136, 2, 31, "Text"],
Cell[28522, 731, 569, 11, 90, "Input",
  InitializationCell->True],
Cell[29094, 744, 277, 6, 90, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[29408, 755, 132, 4, 34, "Section",
  InitializationCell->True],
Cell[29543, 761, 202, 5, 33, "Text",
  InitializationCell->True],
Cell[29748, 768, 1355, 23, 310, "Input",
  InitializationCell->True],
Cell[31106, 793, 2171, 37, 490, "Input",
  InitializationCell->True],
Cell[33280, 832, 1106, 19, 310, "Input",
  InitializationCell->True],
Cell[34389, 853, 712, 14, 150, "Input",
  InitializationCell->True],
Cell[35104, 869, 911, 16, 230, "Input",
  InitializationCell->True],
Cell[36018, 887, 2075, 39, 370, "Input",
  InitializationCell->True],
Cell[38096, 928, 2117, 38, 370, "Input",
  InitializationCell->True],
Cell[40216, 968, 1727, 32, 310, "Input",
  InitializationCell->True],
Cell[41946, 1002, 1770, 32, 310, "Input",
  InitializationCell->True],
Cell[43719, 1036, 83, 2, 30, "Input",
  InitializationCell->True],
Cell[43805, 1040, 1336, 24, 270, "Input",
  InitializationCell->True],
Cell[45144, 1066, 2497, 43, 470, "Input",
  InitializationCell->True],
Cell[47644, 1111, 1417, 28, 284, "Input",
  InitializationCell->True,
  CellTags->"MoreOptions"],
Cell[49064, 1141, 91, 1, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[49192, 1147, 105, 3, 34, "Section"],
Cell[49300, 1152, 245, 5, 34, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

